# Copyright (C) 1998-05  Stephane Galland <galland@arakhne.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.

=pod

=head1 NAME

Bib2HTML::Generator::Lang::English - English support for the generators

=head1 SYNOPSYS

use Bib2HTML::Generator::Lang::English ;

my $gen = Bib2HTML::Generator::Lang::English->new() ;

=head1 DESCRIPTION

Bib2HTML::Generator::Lang::English is a Perl module, which proposes
a English support for all the generators.

=head1 GETTING STARTED

=head2 Initialization

To start a generator script, say something like this:

    use Bib2HTML::Generator::Lang::English;

    my $gen = Bib2HTML::Generator::Lang::English->new() ;

...or something similar.

=head1 METHOD DESCRIPTIONS

This section contains only the methods in English.pm itself.

=over

=cut

package Bib2HTML::Generator::Lang::English;

@ISA = ('Bib2HTML::Generator::Lang');
@EXPORT = qw();
@EXPORT_OK = qw();

use strict;
use vars qw(@ISA @EXPORT @EXPORT_OK $VERSION);
use Exporter;

use Carp ;

use Bib2HTML::Generator::Lang ;
use Bib2HTML::General::Error ;

#------------------------------------------------------
#
# Global vars
#
#------------------------------------------------------

# Version number of language support
my $VERSION = "1.0" ;

# Language definitions
my %LANG_DEFS = (
		 'I18N_LANG_ALL_ELEMENTS' => "All Elements",
		 'I18N_LANG_ARTICLESINSAMEDOMAINS' => "Documents in the same domains",
		 'I18N_LANG_BIB2HTML_COPYRIGHT' => ( "This document was generated by #1.<BR>\n".
						     "Copyright &copy; 1998-05 #2 (under the #3)" ),
		 'I18N_LANG_FIELD_BIBTEX_VERBATIM' => "BibTeX code",
		 'I18N_LANG_FIELD_XML_VERBATIM' => "XML code",
		 'I18N_LANG_DEFAULT_TITLE' => "Bibliography",
		 'I18N_LANG_DOMAIN_TREE' => "Domain Tree",
		 'I18N_LANG_DOMAINS' => "Domains",
		 'I18N_LANG_ENTRY_TYPE_TREE' => "Hierarchical list by entry type",
		 'I18N_LANG_FIELD_ADDRESS' => "Address",
		 'I18N_LANG_FIELD_ABSTRACT' => "Abstract",
		 'I18N_LANG_FIELD_ABSTRACT_KEYWORDS' => "Abstract &amp; Keywords",
		 'I18N_LANG_FIELD_ANNOTATION' => "Annotation",
		 'I18N_LANG_FIELD_AUTHORS' => "Author(s)",
		 'I18N_LANG_FIELD_CHAPTER' => "Chapter of",
		 'I18N_LANG_FIELD_DATE' => "Date",
		 'I18N_LANG_FIELD_DOWNLOAD' => "Download the complete article: #1",
		 'I18N_LANG_FIELD_EDITION' => "Edition",
		 'I18N_LANG_FIELD_EDITORS' => "Editor(s)",
		 'I18N_LANG_FIELD_HOWPUBLISHED' => "How published",
		 'I18N_LANG_FIELD_IN' => "In",
		 'I18N_LANG_FIELD_INSTITUTION' => "Institution",
		 'I18N_LANG_FIELD_ISBN' => "ISBN number",
		 'I18N_LANG_FIELD_ISSN' => "ISSN number",
		 'I18N_LANG_FIELD_JOURNAL' => "Journal",
		 'I18N_LANG_FIELD_KEYWORDS' => "<strong>Keywords</strong>: #1",
		 'I18N_LANG_FIELD_KEYWORDS_TITLE' => "Keywords",
		 'I18N_LANG_FIELD_NOTE' => "Note",
		 'I18N_LANG_FIELD_NUMBER' => "Number",
		 'I18N_LANG_FIELD_ORGANIZATION' => "Organization",
		 'I18N_LANG_FIELD_PAGES' => "Page(s)",
		 'I18N_LANG_FIELD_PDFFILE' => "PDF",
		 'I18N_LANG_FIELD_PUBLISHER' => "Publisher",
		 'I18N_LANG_FIELD_READERS' => "Reader(s)",
		 'I18N_LANG_FIELD_SCHOOL' => "School",
		 'I18N_LANG_FIELD_SERIES' => "Series",
		 'I18N_LANG_FIELD_TITLE' => "Title",
		 'I18N_LANG_FIELD_TYPE' => "Type",
		 'I18N_LANG_FIELD_URL' => "URL",
		 'I18N_LANG_FIELD_VOLUME' => "Volume",
		 'I18N_LANG_FIELD_YEAR' => "Year",
		 'I18N_LANG_FORMAT_NAME' => "l{ (v)}{ f.}{, j}",
		 'I18N_LANG_FORMAT_NAMES' => "{ and }{, }",
		 'I18N_LANG_FRAME_TITLE_AUTHORS' => "Authors",
		 'I18N_LANG_FRAME_TITLE_TYPES' => "Types",
		 'I18N_LANG_FRAMES' => "Frames",
		 'I18N_LANG_INDEX' => "Index",
		 'I18N_LANG_INDEX_COMMENT_ARTICLE' => "article",
		 'I18N_LANG_INDEX_COMMENT_AUTHOR' => "author",
		 'I18N_LANG_INDEX_COMMENT_BOOKTITLE' => "booktitle",
		 'I18N_LANG_INDEX_COMMENT_EDITOR' => "editor",
		 'I18N_LANG_INDEX_COMMENT_HOWPUBLISHED' => "publication mean",
		 'I18N_LANG_INDEX_COMMENT_INSTITUTION' => "institution",
		 'I18N_LANG_INDEX_COMMENT_PUBLISHER' => "publisher",
		 'I18N_LANG_INDEX_COMMENT_SCHOOL' => "school",
		 'I18N_LANG_INDEX_COMMENT_TITLE' => "title",
		 'I18N_LANG_NEXT' => "Next",
		 'I18N_LANG_NO_DATE' => "Not dated",
		 'I18N_LANG_NO_FRAME' => "No Frame",
		 'I18N_LANG_NO_FRAME_ALERT' => ( "<H2>Frame Alert</H2>\n".
						 "<P>This document is designed to be ".
						 "viewed using the frames ".
						 "feature. If you see this message, ".
						 "you are using a ".
						 "non-frame-capable web client.<BR>\n".
						 "Link to <A HREF=\"#1\">".
						 "Non-frame version.</A>.<BR>\n#2" ),
		 'I18N_LANG_OVERVIEW' => "Overview",
		 'I18N_LANG_P_ARTICLE' => "Articles",
		 'I18N_LANG_P_BOOK' => "Books",
		 'I18N_LANG_P_BOOKLET' => "Not-sponsored books",
		 'I18N_LANG_P_INBOOK' => "Book parts",
		 'I18N_LANG_P_INCOLLECTION' => "In a collection",
		 'I18N_LANG_P_INPROCEEDINGS' => "In proceedings",
		 'I18N_LANG_P_MANUAL' => "Technical manuals",
		 'I18N_LANG_P_MASTERTHESIS' => "Master's thesis",
		 'I18N_LANG_P_MISC' => 'Miscellaneous documents',
		 'I18N_LANG_P_PHDTHESIS' => "PhD thesis",
		 'I18N_LANG_P_PROCEEDINGS' => "Conference proceedings",
		 'I18N_LANG_P_TECHREPORT' => "Technical reports",
		 'I18N_LANG_P_UNPUBLISHED' => "Unpublished",
		 'I18N_LANG_PREV' => "Prev",
		 'I18N_LANG_TREE' => "Tree",
		 'I18N_LANG_S_ARTICLE' => "Article",
		 'I18N_LANG_S_BOOK' => "Book",
		 'I18N_LANG_S_BOOKLET' => "Not-sponsored book",
		 'I18N_LANG_S_INBOOK' => "Book part",
		 'I18N_LANG_S_INCOLLECTION' => "In a collection",
		 'I18N_LANG_S_INPROCEEDINGS' => "In proceedings",
		 'I18N_LANG_S_MANUAL' => "Technical manual",
		 'I18N_LANG_S_MASTERTHESIS' => "Master's thesis",
		 'I18N_LANG_S_MISC' => 'Miscellaneous document',
		 'I18N_LANG_S_PHDTHESIS' => "PhD thesis",
		 'I18N_LANG_S_PROCEEDINGS' => "Conference proceedings",
		 'I18N_LANG_S_TECHREPORT' => "Technical report",
		 'I18N_LANG_S_UNPUBLISHED' => "Unpublished",
		 'I18N_LANG_SMALL_IN' => "in:&nbsp;#1",
		 'I18N_LANG_SUBMIT_BUG' => "Submit a bug",
		) ;

#------------------------------------------------------
#
# Constructor
#
#------------------------------------------------------

sub new($$) : method {
  my $proto = shift;
  my $class = ref($proto) || $proto;
  my $self = $class->SUPER::new("English",\%LANG_DEFS) ;
  bless( $self, $class );
  return $self;
}

1;
__END__

=back

=head1 COPYRIGHT

(c) Copyright 1998-05 Stphane Galland <galland@arakhne.org>, under GPL.

=head1 AUTHORS

=over

=item *

Conceived and initially developed by Stphane Galland E<lt>galland@arakhne.orgE<gt>.

=back

=head1 SEE ALSO

bib2html.pl
