# Copyright (C) 1998-05  Stephane Galland <galland@arakhne.org>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; see the file COPYING.  If not, write to
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.

=pod

=head1 NAME

Bib2HTML::Generator::Lang::Portuguese - Portuguese support for the generators

=head1 SYNOPSYS

use Bib2HTML::Generator::Lang::Portuguese ;

my $gen = Bib2HTML::Generator::Lang::Portuguese->new() ;

=head1 DESCRIPTION

Bib2HTML::Generator::Lang::Portuguese is a Perl module, which proposes
a Portuguese support for all the generators.

=head1 GETTING STARTED

=head2 Initialization

To start a generator script, say something like this:

    use Bib2HTML::Generator::Lang::Portuguese;

    my $gen = Bib2HTML::Generator::Lang::Portuguese->new() ;

...or something similar.

=head1 METHOD DESCRIPTIONS

This section contains only the methods in Portuguese.pm itself.

=over

=cut

package Bib2HTML::Generator::Lang::Portuguese;

@ISA = ('Bib2HTML::Generator::Lang');
@EXPORT = qw();
@EXPORT_OK = qw();

use strict;
use vars qw(@ISA @EXPORT @EXPORT_OK $VERSION);
use Exporter;

use Carp ;

use Bib2HTML::Generator::Lang ;
use Bib2HTML::General::Error ;

#------------------------------------------------------
#
# Global vars
#
#------------------------------------------------------

# Version number of language support
my $VERSION = "1.0" ;

# Language definitions
my %LANG_DEFS = (
		 'I18N_LANG_ALL_ELEMENTS' => "Todos os Elementos",
		 'I18N_LANG_ARTICLESINSAMEDOMAINS' => "Documentos nos mesmos dom&iacute;nios",
		 'I18N_LANG_BIB2HTML_COPYRIGHT' => ( "Este documento foi gerado por #1.<BR>\n".
						     "Copyright &copy; 1998-05 #2 (licen&ccedil;a #3)" ),
		 'I18N_LANG_FIELD_BIBTEX_VERBATIM' => "C&oacute;digo BibTeX",
		 'I18N_LANG_FIELD_XML_VERBATIM' => "C&oacute;digo XML",
		 'I18N_LANG_DEFAULT_TITLE' => "Bibliografia",
		 'I18N_LANG_DOMAIN_TREE' => "&Aacute;rvore de dom&iacute;nios",
		 'I18N_LANG_DOMAINS' => "Dom&iacute;nios",
		 'I18N_LANG_ENTRY_TYPE_TREE' => "Lista hier&aacute;rquiaca por tipo de entrada",
		 'I18N_LANG_FIELD_ADDRESS' => "Endere&ccedil;o",
		 'I18N_LANG_FIELD_ABSTRACT' => "Resumo",
		 'I18N_LANG_FIELD_ABSTRACT_KEYWORDS' => "Resumo &amp; Palavras-chave",
		 'I18N_LANG_FIELD_ANNOTATION' => "Anota&ccedil;&otilde;es",
		 'I18N_LANG_FIELD_AUTHORS' => "Autor(es)",
		 'I18N_LANG_FIELD_CHAPTER' => "Cap&iacute;tulo de",
		 'I18N_LANG_FIELD_DATE' => "Data",
		 'I18N_LANG_FIELD_DOWNLOAD' => "Obter o artigo completo: #1",
		 'I18N_LANG_FIELD_EDITION' => "Edi&ccedil;&atilde;o",
		 'I18N_LANG_FIELD_EDITORS' => "Editor(es)",
		 'I18N_LANG_FIELD_HOWPUBLISHED' => "Publicado como",
		 'I18N_LANG_FIELD_IN' => "Em",
		 'I18N_LANG_FIELD_INSTITUTION' => "Institui&ccedil;&atilde;o",
		 'I18N_LANG_FIELD_ISBN' => "N&uacute;mero ISBN",
		 'I18N_LANG_FIELD_ISSN' => "N&uacute;mero ISSN",
		 'I18N_LANG_FIELD_JOURNAL' => "Journal",
		 'I18N_LANG_FIELD_KEYWORDS' => "<strong>Palavras-chave</strong>: #1",
		 'I18N_LANG_FIELD_KEYWORDS_TITLE' => "Palavras-chave",
		 'I18N_LANG_FIELD_NOTE' => "Nota",
		 'I18N_LANG_FIELD_NUMBER' => "N&uacute;mero",
		 'I18N_LANG_FIELD_ORGANIZATION' => "Organiza&ccedil;&atilde;o",
		 'I18N_LANG_FIELD_PAGES' => "P&aacute;gina(s)",
		 'I18N_LANG_FIELD_PDFFILE' => "PDF",
		 'I18N_LANG_FIELD_PUBLISHER' => "Editora",
		 'I18N_LANG_FIELD_READERS' => "Leitor(es)",
		 'I18N_LANG_FIELD_SCHOOL' => "Escola",
		 'I18N_LANG_FIELD_SERIES' => "S&eacute;ries",
		 'I18N_LANG_FIELD_TITLE' => "Ttulo",
		 'I18N_LANG_FIELD_TYPE' => "Tipo",
		 'I18N_LANG_FIELD_URL' => "URL",
		 'I18N_LANG_FIELD_VOLUME' => "Volume",
		 'I18N_LANG_FIELD_YEAR' => "Ano",
		 'I18N_LANG_FORMAT_NAME' => "l{ (v)}{ f.}{, j}",
		 'I18N_LANG_FORMAT_NAMES' => "{ e }{, }",
		 'I18N_LANG_FRAME_TITLE_AUTHORS' => "Autores",
		 'I18N_LANG_FRAME_TITLE_TYPES' => "Tipos",
		 'I18N_LANG_FRAMES' => "<em>Frames</em>",
		 'I18N_LANG_INDEX' => "&Iacute;ndice",
		 'I18N_LANG_INDEX_COMMENT_ARTICLE' => "artigo",
		 'I18N_LANG_INDEX_COMMENT_AUTHOR' => "autor",
		 'I18N_LANG_INDEX_COMMENT_BOOKTITLE' => "T&iacute;tulo de livro",
		 'I18N_LANG_INDEX_COMMENT_EDITOR' => "editor",
		 'I18N_LANG_INDEX_COMMENT_HOWPUBLISHED' => "meio de publica&ccedil;&atilde;o",
		 'I18N_LANG_INDEX_COMMENT_INSTITUTION' => "institui&ccdeil;&atilde;o",
		 'I18N_LANG_INDEX_COMMENT_PUBLISHER' => "editor",
		 'I18N_LANG_INDEX_COMMENT_SCHOOL' => "escola",
		 'I18N_LANG_INDEX_COMMENT_TITLE' => "t&iacute;tulo",
		 'I18N_LANG_NEXT' => "Pr&oacute;ximo",
		 'I18N_LANG_NO_DATE' => "N&atilde;o datado",
		 'I18N_LANG_NO_FRAME' => "Sem <em>Frames</em>",
		 'I18N_LANG_NO_FRAME_ALERT' => ( "<H2>Alerta de Frames</H2>\n".
						 "<P>Este documento foi concebido para ser ".
						 "visualizado usando a funcionalidade ".
						 "de <en>frames</em>. A visualiza&ccedil,&atilde;o desta ".
						 "mensagem indica que est&aacute; a usar um <em>browser</em> ".
						 "que n&atilde;o suport <em>frames</em>.<BR>\n".
						 "<em>Link</em> para uma <A HREF=\"#1\">".
						 "vers&atilde;o sem <em>frames</em></A>.<BR>\n#2" ),
		 'I18N_LANG_OVERVIEW' => "P&aacute;gina&nbsp;principal",
		 'I18N_LANG_P_ARTICLE' => "Artigos",
		 'I18N_LANG_P_BOOK' => "Livros",
		 'I18N_LANG_P_BOOKLET' => "Livros sem editor",
		 'I18N_LANG_P_INBOOK' => "Partes de livros",
		 'I18N_LANG_P_INCOLLECTION' => "Artigos numa colec&ccedil;&atilde;o",
		 'I18N_LANG_P_INPROCEEDINGS' => "Artigos em actas de confer&ecirc;ncias",
		 'I18N_LANG_P_MANUAL' => "Manuais t&eacute;cnicos",
		 'I18N_LANG_P_MASTERTHESIS' => "Teses de mestrado",
		 'I18N_LANG_P_MISC' => 'Documentos diversos',
		 'I18N_LANG_P_PHDTHESIS' => "Teses de doutoramento",
		 'I18N_LANG_P_PROCEEDINGS' => "Actas de confer&ecirc;ncias",
		 'I18N_LANG_P_TECHREPORT' => "Relat&oacute;rios t&eacute;cnicos",
		 'I18N_LANG_P_UNPUBLISHED' => "N&atilde;o publicados",
		 'I18N_LANG_PREV' => "Anterior",
		 'I18N_LANG_TREE' => "&Aacute;rvore",
		 'I18N_LANG_S_ARTICLE' => "Artigo",
		 'I18N_LANG_S_BOOK' => "Livro",
		 'I18N_LANG_S_BOOKLET' => "Livros sem editor",
		 'I18N_LANG_S_INBOOK' => "Parte de livro",
		 'I18N_LANG_S_INCOLLECTION' => "Artigo numa colec&ccedil;&atilde;o",
		 'I18N_LANG_S_INPROCEEDINGS' => "Artigo em actas de confer&ecirc;ncias",
		 'I18N_LANG_S_MANUAL' => "Manual t&eacute;cnico",
		 'I18N_LANG_S_MASTERTHESIS' => "Tese de mestrado",
		 'I18N_LANG_S_MISC' => 'Documentos diverso',
		 'I18N_LANG_S_PHDTHESIS' => "Tese de doutoramento",
		 'I18N_LANG_S_PROCEEDINGS' => "Actas de confer&ecirc;ncia",
		 'I18N_LANG_S_TECHREPORT' => "Relat&oacute;rio t&eacute;cnico",
		 'I18N_LANG_S_UNPUBLISHED' => "N&atilde;o publicado",
		 'I18N_LANG_SMALL_IN' => "em:&nbsp;#1",
		 'I18N_LANG_SUBMIT_BUG' => "Submeter um relat&oacute;rio de erro",
		) ;

#------------------------------------------------------
#
# Constructor
#
#------------------------------------------------------

sub new($$) : method {
  my $proto = shift;
  my $class = ref($proto) || $proto;
  my $self = $class->SUPER::new("Portuguese",\%LANG_DEFS) ;
  bless( $self, $class );
  return $self;
}

1;
__END__

=back

=head1 COPYRIGHT

(c) Copyright 1998-05 Stphane Galland <galland@arakhne.org>, under GPL.

=head1 AUTHORS

=over

=item *

Conceived and initially developed by Stphane Galland E<lt>galland@arakhne.orgE<gt>.
Spanish translation by Joao LOURENCO E<lt>joao.lourenco@di.fct.unl.ptE<gt>.

=back

=head1 SEE ALSO

bib2html.pl
